@@ -1,13 +1,15 @@
 ;;; hl-todo.el --- Highlight TODO and similar keywords  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2013-2025 Jonas Bernoulli
+;; Copyright (C) 2013-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.hl-todo@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/tarsius/hl-todo
 ;; Keywords: convenience
 
-;; Package-Version: 3.9.0
-;; Package-Requires: ((emacs "26.1") (compat "30.1"))
+;; Package-Version: 3.9.3
+;; Package-Requires: (
+;;     (emacs  "26.1")
+;;     (compat "30.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -198,6 +200,9 @@ controls which of the two it is."
     by any delimiters.  Use this if you want the TODO in fooTODObar
     to be highlighted.
 
+`hl-todo-rgrep' uses \\< and \\> for `symbol' as well, because grep
+does not support \\_< and \\_>.
+
 If you want to prevent keyword fontification if certain characters
 appear next to them, then you have to modify `hl-todo-syntax-table'.
 For example, if you do not want the TODO in !TODO to be highlighted,
@@ -246,11 +251,11 @@ from `text-mode-syntax-table'.")
 
 (defvar-local hl-todo--regexp nil)
 
-(defsubst hl-todo--regexp ()
+(defsubst hl-todo--regexp (&optional no-symbol)
   "Return regular expression matching TODO or similar keyword."
-  (or hl-todo--regexp (hl-todo--setup-regexp)))
+  (or hl-todo--regexp (hl-todo--setup-regexp no-symbol)))
 
-(defun hl-todo--setup-regexp ()
+(defun hl-todo--setup-regexp (&optional no-symbol)
   "Setup keyword regular expression.
 See the function `hl-todo--regexp'."
   (when-let ((bomb (assoc "???" hl-todo-keyword-faces)))
@@ -260,19 +265,21 @@ See the function `hl-todo--regexp'."
     ;; in the regexp search taking forever.
     (setq hl-todo-keyword-faces (delete bomb hl-todo-keyword-faces)))
   (setq hl-todo--regexp
-        (concat "\\(?1:"
+        (concat "\\("
                 (pcase hl-todo-keyword-delimiters
-                  ('symbol "\\_<")
+                  ('symbol (if no-symbol "\\<" "\\_<"))
                   ('word   "\\<")
                   (_       ""))
-                "\\(?2:" (mapconcat #'car hl-todo-keyword-faces "\\|") "\\)"
+                "\\(" (mapconcat #'car hl-todo-keyword-faces "\\|") "\\)"
                 (pcase hl-todo-keyword-delimiters
-                  ('symbol "\\_>")
-                  ('word    "\\>")
-                  (_           ""))
+                  ('symbol (if no-symbol "\\>" "\\_>"))
+                  ('word   "\\>")
+                  (_       ""))
                 (and (not (equal hl-todo-highlight-punctuation ""))
                      (concat "[" hl-todo-highlight-punctuation "]"
-                             (if hl-todo-require-punctuation "+" "*")))
+                             (if hl-todo-require-punctuation
+                                 (if no-symbol "\\+" "+")
+                               "*")))
                 "\\)")))
 
 (defun hl-todo--search (&optional regexp bound backward)
@@ -422,16 +429,16 @@ argument does not matter; with any prefix you can edit the
 constructed shell command line before it is executed.
 Also see option `hl-todo-keyword-faces'."
   (interactive
-   (progn
-     (require 'grep)
-     (grep-compute-defaults)
-     (unless grep-find-template
-       (error "grep.el: No `grep-find-template' available"))
-     (let ((regexp (with-temp-buffer (hl-todo--regexp))))
-       (list regexp
-             (grep-read-files regexp)
-             (read-directory-name "Base directory: " nil default-directory t)
-             current-prefix-arg))))
+    (progn
+      (require 'grep)
+      (grep-compute-defaults)
+      (unless grep-find-template
+        (error "grep.el: No `grep-find-template' available"))
+      (let ((regexp (with-temp-buffer (hl-todo--regexp t))))
+        (list regexp
+              (grep-read-files regexp)
+              (read-directory-name "Base directory: " nil default-directory t)
+              current-prefix-arg))))
   (rgrep regexp files dir confirm))
 
 ;;;###autoload
@@ -498,37 +505,37 @@ If `hl-todo-require-punctuation' is non-nil and
 `hl-todo-highlight-punctuation' contains a single character,
 then append that character to the inserted string."
   (interactive
-   (list (completing-read
-          "Insert keyword: "
-          (mapcan (pcase-lambda (`(,keyword . ,face))
-                    (and (equal (regexp-quote keyword) keyword)
-                         (list (propertize keyword 'face
-                                           (hl-todo--combine-face face)))))
-                  hl-todo-keyword-faces))))
+    (list (completing-read
+           "Insert keyword: "
+           (mapcan (pcase-lambda (`(,keyword . ,face))
+                     (and (equal (regexp-quote keyword) keyword)
+                          (list (propertize keyword 'face
+                                            (hl-todo--combine-face face)))))
+                   hl-todo-keyword-faces))))
   (let ((keyword (if (and hl-todo-require-punctuation
                           (length= hl-todo-highlight-punctuation 1))
                      (concat keyword hl-todo-highlight-punctuation)
                    keyword)))
     (cond
-     ((hl-todo--inside-comment-or-string-p)
-      (insert (concat (and (not (memq (char-before) '(?\s ?\t))) " ")
-                      keyword
-                      (and (not (memq (char-after) '(?\s ?\t ?\n))) " "))))
-     ((and (eolp)
-           (not (looking-back "^[\s\t]*" (line-beginning-position) t)))
-      (insert (concat (and (not (memq (char-before) '(?\s ?\t))) " ")
-                      (format "%s %s " comment-start keyword))))
-     (t
-      (goto-char (line-beginning-position))
-      (insert (cond ((derived-mode-p 'lisp-mode 'emacs-lisp-mode)
-                     (format "%s%s %s" comment-start comment-start keyword))
-                    ((string-suffix-p " " comment-start)
-                     (format "%s%s" comment-start keyword))
-                    (t
-                     (format "%s %s" comment-start keyword))))
-      (unless (looking-at "[\s\t]*$")
-        (save-excursion (insert "\n")))
-      (indent-region (line-beginning-position) (line-end-position))))))
+      ((hl-todo--inside-comment-or-string-p)
+       (insert (concat (and (not (memq (char-before) '(?\s ?\t))) " ")
+                       keyword
+                       (and (not (memq (char-after) '(?\s ?\t ?\n))) " "))))
+      ((and (eolp)
+            (not (looking-back "^[\s\t]*" (line-beginning-position) t)))
+       (insert (concat (and (not (memq (char-before) '(?\s ?\t))) " ")
+                       (format "%s %s " comment-start keyword))))
+      (t
+       (goto-char (line-beginning-position))
+       (insert (cond ((derived-mode-p 'lisp-mode 'emacs-lisp-mode)
+                      (format "%s%s %s" comment-start comment-start keyword))
+                     ((string-suffix-p " " comment-start)
+                      (format "%s%s" comment-start keyword))
+                     (t
+                      (format "%s %s" comment-start keyword))))
+       (unless (looking-at "[\s\t]*$")
+         (save-excursion (insert "\n")))
+       (indent-region (line-beginning-position) (line-end-position))))))
 
 ;;;###autoload
 (defun hl-todo-search-and-highlight ()
@@ -546,5 +553,6 @@ Intended to be added to `magit-revision-wash-message-hook' and
 (provide 'hl-todo)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
+;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; hl-todo.el ends here
